@@ -19,7 +19,7 @@
 RDS DB template generator
 """
 
-from troposphere import Sub, Ref, If, GetAtt
+from troposphere import Sub, Ref, If, GetAtt, AWS_NO_VALUE
 from troposphere.ec2 import SecurityGroup
 from troposphere.rds import (
     DBSubnetGroup,
@@ -36,7 +36,7 @@ from troposphere.secretsmanager import (
 
 from ecs_composex.common import build_template, cfn_conditions
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
-from ecs_composex.common.outputs import formatted_outputs
+from ecs_composex.common.outputs import ComposeXOutput
 from ecs_composex.rds import rds_conditions
 from ecs_composex.rds.rds_parameter_groups_helper import (
     get_family_from_engine_version,
@@ -60,15 +60,8 @@ from ecs_composex.rds.rds_params import (
     DB_EXPORT_PORT_T,
     DB_EXPORT_SG_ID_T,
 )
-from ecs_composex.vpc.vpc_conditions import (
-    USE_VPC_MAP_ID_CON_T,
-    USE_VPC_MAP_ID_CON,
-    NOT_USE_VPC_MAP_ID_CON_T,
-    NOT_USE_VPC_MAP_ID_CON,
-)
 from ecs_composex.vpc.vpc_params import (
     VPC_ID,
-    VPC_MAP_ID,
     STORAGE_SUBNETS,
 )
 
@@ -89,15 +82,15 @@ def add_db_outputs(db_template, db_name):
     :param str db_name: Name of the database
     """
     db_template.add_output(
-        formatted_outputs(
+        ComposeXOutput(
+            db_name,
             [
-                {DB_EXPORT_SECRET_ARN_T: Ref(DB_SECRET_T)},
-                {DB_EXPORT_PORT_T: GetAtt(CLUSTER_T, "Endpoint.Port")},
-                {DB_NAME_T: Ref(DATABASE_T)},
-                {DB_EXPORT_SG_ID_T: GetAtt(DB_SG_T, "GroupId")},
+                (DB_EXPORT_SECRET_ARN_T, "SecretArn", Ref(DB_SECRET_T)),
+                (DB_EXPORT_PORT_T, "Port", GetAtt(CLUSTER_T, "Endpoint.Port")),
+                (DB_NAME_T, "DbName", Ref(DATABASE_T)),
+                (DB_EXPORT_SG_ID_T, "GroupId", GetAtt(DB_SG_T, "GroupId")),
             ],
-            obj_name=db_name,
-        )
+        ).outputs
     )
 
 
@@ -186,7 +179,7 @@ def add_db_secret(template):
     )
 
 
-def add_instance(template, db, **kwargs):
+def add_instance(template):
     """
     Function to add DB Instance(s)
 
@@ -198,7 +191,7 @@ def add_instance(template, db, **kwargs):
         Engine=Ref(DB_ENGINE_NAME),
         EngineVersion=Ref(DB_ENGINE_VERSION),
         StorageType=If(
-            rds_conditions.USE_CLUSTER_CON_T, Ref("AWS::NoValue"), Ref(DB_STORAGE_TYPE)
+            rds_conditions.USE_CLUSTER_CON_T, Ref(AWS_NO_VALUE), Ref(DB_STORAGE_TYPE)
         ),
         DBSubnetGroupName=If(
             rds_conditions.NOT_USE_CLUSTER_CON_T,
@@ -207,38 +200,38 @@ def add_instance(template, db, **kwargs):
                 Ref(CLUSTER_SUBNET_GROUP),
                 Ref(DBS_SUBNET_GROUP),
             ),
-            Ref("AWS::NoValue"),
+            Ref(AWS_NO_VALUE),
         ),
         AllocatedStorage=If(
             rds_conditions.USE_CLUSTER_CON_T,
-            Ref("AWS::NoValue"),
+            Ref(AWS_NO_VALUE),
             Ref(DB_STORAGE_CAPACITY),
         ),
         DBInstanceClass=Ref(DB_INSTANCE_CLASS),
         MasterUsername=If(
             rds_conditions.USE_CLUSTER_OR_SNAPSHOT_CON_T,
-            Ref("AWS::NoValue"),
+            Ref(AWS_NO_VALUE),
             Sub(
                 f"{{{{resolve:secretsmanager:${{{DB_SECRET_T}}}:SecretString:username}}}}"
             ),
         ),
         DBClusterIdentifier=If(
-            rds_conditions.USE_CLUSTER_CON_T, Ref(CLUSTER_T), Ref("AWS::NoValue")
+            rds_conditions.USE_CLUSTER_CON_T, Ref(CLUSTER_T), Ref(AWS_NO_VALUE)
         ),
         MasterUserPassword=If(
             rds_conditions.USE_CLUSTER_CON_T,
-            Ref("AWS::NoValue"),
+            Ref(AWS_NO_VALUE),
             Sub(
                 f"{{{{resolve:secretsmanager:${{{DB_SECRET_T}}}:SecretString:password}}}}"
             ),
         ),
         VPCSecurityGroups=If(
-            rds_conditions.USE_CLUSTER_CON_T, Ref("AWS::NoValue"), [Ref(DB_SG_T)]
+            rds_conditions.USE_CLUSTER_CON_T, Ref(AWS_NO_VALUE), [Ref(DB_SG_T)]
         ),
     )
 
 
-def add_cluster(template, db, **kwargs):
+def add_cluster(template):
     """
     Function to add the cluster to the template
 
@@ -258,7 +251,7 @@ def add_cluster(template, db, **kwargs):
         DatabaseName=Ref(DB_NAME),
         MasterUsername=If(
             rds_conditions.USE_CLUSTER_AND_SNAPSHOT_CON_T,
-            Ref("AWS::NoValue"),
+            Ref(AWS_NO_VALUE),
             Sub(
                 f"{{{{resolve:secretsmanager:${{{DB_SECRET_T}}}:SecretString:username}}}}"
             ),
@@ -271,9 +264,9 @@ def add_cluster(template, db, **kwargs):
             If(
                 rds_conditions.USE_DB_SNAPSHOT_CON_T,
                 Ref(DB_SNAPSHOT_ID),
-                Ref("AWS::NoValue"),
+                Ref(AWS_NO_VALUE),
             ),
-            Ref("AWS::NoValue"),
+            Ref(AWS_NO_VALUE),
         ),
         Engine=Ref(DB_ENGINE_NAME),
         EngineVersion=Ref(DB_ENGINE_VERSION),
@@ -294,6 +287,12 @@ def add_parameter_group(template, db):
         db["Properties"][DB_ENGINE_NAME.title],
         db["Properties"][DB_ENGINE_VERSION.title],
     )
+    if not db_family:
+        raise ValueError(
+            "Failed to retrieve the DB Family for "
+            f"{db['Properties']['DB_ENGINE_NAME.title']}"
+            f"{db['Properties']['DB_ENGINE_VERSION.title']}"
+        )
     db_settings = get_family_settings(db_family)
     DBParameterGroup(
         PARAMETER_GROUP_T,
@@ -324,7 +323,6 @@ def init_database_template(db_name):
         f"Template for RDS DB {db_name}",
         [
             VPC_ID,
-            VPC_MAP_ID,
             DB_ENGINE_NAME,
             DB_ENGINE_VERSION,
             STORAGE_SUBNETS,
@@ -369,13 +367,11 @@ def init_database_template(db_name):
         rds_conditions.USE_CLUSTER_OR_SNAPSHOT_CON_T,
         rds_conditions.USE_CLUSTER_OR_SNAPSHOT_CON,
     )
-    template.add_condition(USE_VPC_MAP_ID_CON_T, USE_VPC_MAP_ID_CON)
-    template.add_condition(NOT_USE_VPC_MAP_ID_CON_T, NOT_USE_VPC_MAP_ID_CON)
     create_db_subnet_group(template, True)
     return template
 
 
-def generate_database_template(db_name, db, **kwargs):
+def generate_database_template(db_name, db):
     """
     Function to generate the database template
     :param str db_name: name of the database as defined in the compose file
@@ -386,10 +382,10 @@ def generate_database_template(db_name, db, **kwargs):
     :rtype: troposphere.Template
     """
     db_template = init_database_template(db_name)
-    add_cluster(db_template, db, **kwargs)
+    add_cluster(db_template)
     add_db_secret(db_template)
     add_db_sg(db_template, db_name)
-    add_instance(db_template, None, **kwargs)
+    add_instance(db_template)
     add_parameter_group(db_template, db)
     add_db_outputs(db_template, db_name)
     return db_template
